summaryrefslogtreecommitdiffstats
path: root/konq-plugins/fsview
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:12 -0600
commit6b45a7b7b2a804ccb2d522eb9ba6423fedb59b8f (patch)
treea08b27e3f4fde1ed82a5f061a2725998e8012f93 /konq-plugins/fsview
parentca82971624269719d487c6f7980d7237f9420036 (diff)
downloadtdeaddons-6b45a7b7b2a804ccb2d522eb9ba6423fedb59b8f.tar.gz
tdeaddons-6b45a7b7b2a804ccb2d522eb9ba6423fedb59b8f.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit ca82971624269719d487c6f7980d7237f9420036.
Diffstat (limited to 'konq-plugins/fsview')
-rw-r--r--konq-plugins/fsview/fsview.cpp20
-rw-r--r--konq-plugins/fsview/fsview_part.cpp6
-rw-r--r--konq-plugins/fsview/inode.cpp34
-rw-r--r--konq-plugins/fsview/inode.h2
-rw-r--r--konq-plugins/fsview/treemap.cpp176
-rw-r--r--konq-plugins/fsview/treemap.h28
6 files changed, 133 insertions, 133 deletions
diff --git a/konq-plugins/fsview/fsview.cpp b/konq-plugins/fsview/fsview.cpp
index 931c43f..830bb3d 100644
--- a/konq-plugins/fsview/fsview.cpp
+++ b/konq-plugins/fsview/fsview.cpp
@@ -94,12 +94,12 @@ FSView::FSView(Inode* base, TQWidget* parent, const char* name)
double s;
TQString str;
for (i=1;i<=ccount;i++) {
- str = TQString("Dir%1").arg(i);
+ str = TQString("Dir%1").tqarg(i);
if (!cconfig.hasKey(str)) continue;
str = cconfig.readPathEntry(str);
- s = cconfig.readDoubleNumEntry(TQString("Size%1").arg(i), 0.0);
- f = cconfig.readNumEntry(TQString("Files%1").arg(i), 0);
- d = cconfig.readNumEntry(TQString("Dirs%1").arg(i), 0);
+ s = cconfig.readDoubleNumEntry(TQString("Size%1").tqarg(i), 0.0);
+ f = cconfig.readNumEntry(TQString("Files%1").tqarg(i), 0);
+ d = cconfig.readNumEntry(TQString("Dirs%1").tqarg(i), 0);
if (s==0.0 || f==0 || d==0) continue;
setDirMetric(str, s, f, d);
}
@@ -147,7 +147,7 @@ void FSView::setPath(TQString p)
b->setPeer(d);
- setCaption(TQString("%1 - FSView").arg(_path));
+ setCaption(TQString("%1 - FSView").tqarg(_path));
requestUpdate(b);
}
@@ -286,7 +286,7 @@ void FSView::contextMenu(TreeMapItem* i, const TQPoint& p)
popup.insertItem(i18n("Refresh"), 5);
popup.setItemEnabled(5, !_sm.scanRunning());
- if (i) popup.insertItem(i18n("Refresh '%1'").arg(i->text(0)), 4);
+ if (i) popup.insertItem(i18n("Refresh '%1'").tqarg(i->text(0)), 4);
popup.insertSeparator();
addDepthStopItems(dpopup, 1001, i);
popup.insertItem(i18n("Stop at Depth"), dpopup, 1000);
@@ -331,10 +331,10 @@ void FSView::saveMetric(KConfigGroup* g)
TQMap<TQString, MetricEntry>::iterator it;
int c = 1;
for (it=_dirMetric.begin();it!=_dirMetric.end();++it) {
- g->writePathEntry(TQString("Dir%1").arg(c), it.key());
- g->writeEntry(TQString("Size%1").arg(c), (*it).size);
- g->writeEntry(TQString("Files%1").arg(c), (*it).fileCount);
- g->writeEntry(TQString("Dirs%1").arg(c), (*it).dirCount);
+ g->writePathEntry(TQString("Dir%1").tqarg(c), it.key());
+ g->writeEntry(TQString("Size%1").tqarg(c), (*it).size);
+ g->writeEntry(TQString("Files%1").tqarg(c), (*it).fileCount);
+ g->writeEntry(TQString("Dirs%1").tqarg(c), (*it).dirCount);
c++;
}
g->writeEntry("Count", c-1);
diff --git a/konq-plugins/fsview/fsview_part.cpp b/konq-plugins/fsview/fsview_part.cpp
index 493a0e1..547335b 100644
--- a/konq-plugins/fsview/fsview_part.cpp
+++ b/konq-plugins/fsview/fsview_part.cpp
@@ -20,7 +20,7 @@
* The KPart embedding the FSView widget
*/
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqtimer.h>
#include <tqwhatsthis.h>
@@ -74,7 +74,7 @@ void FSJob::progressSlot(int percent, int dirs, const TQString& cDir)
emitPercent(percent, 100);
slotInfoMessage(this, i18n("Read 1 folder, in %1",
"Read %n folders, in %1",
- dirs ).arg(cDir));
+ dirs ).tqarg(cDir));
}
else
slotInfoMessage(this, i18n("1 folder", "%n folders", dirs));
@@ -344,7 +344,7 @@ void FSViewBrowserExtension::trash()
void FSViewBrowserExtension::copySelection( bool move )
{
KonqDrag *urlData = KonqDrag::newDrag( _view->selectedUrls(), move );
- TQApplication::clipboard()->setData( urlData );
+ TQApplication::tqclipboard()->setData( urlData );
}
void FSViewBrowserExtension::editMimeType()
diff --git a/konq-plugins/fsview/inode.cpp b/konq-plugins/fsview/inode.cpp
index 6f5073c..d4875c2 100644
--- a/konq-plugins/fsview/inode.cpp
+++ b/konq-plugins/fsview/inode.cpp
@@ -168,7 +168,7 @@ void Inode::destroyed(ScanDir* d)
{
if (_dirPeer == d) _dirPeer = 0;
- // remove children
+ // remove tqchildren
clear();
}
@@ -179,15 +179,15 @@ void Inode::destroyed(ScanFile* f)
-TreeMapItemList* Inode::children()
+TreeMapItemList* Inode::tqchildren()
{
if (!_dirPeer) return 0;
- if (!_children) {
+ if (!_tqchildren) {
if (!_dirPeer->scanStarted()) return 0;
- _children = new TreeMapItemList;
- _children->setAutoDelete(true);
+ _tqchildren = new TreeMapItemList;
+ _tqchildren->setAutoDelete(true);
setSorting(-1);
@@ -215,7 +215,7 @@ TreeMapItemList* Inode::children()
_resortNeeded = false;
}
- return _children;
+ return _tqchildren;
}
@@ -284,7 +284,7 @@ TQColor Inode::backColor() const
if (id>0) n = TQString::number(id);
if (n.isEmpty())
- return widget()->colorGroup().button();
+ return widget()->tqcolorGroup().button();
const char* str = n.ascii();
int h = 0, s = 100;
@@ -325,21 +325,21 @@ TQString Inode::text(int i) const
double s = size();
if (s < 1000)
- text = TQString("%1 B").arg((int)(s+.5));
+ text = TQString("%1 B").tqarg((int)(s+.5));
else if (s < 10 * 1024)
- text = TQString("%1 kB").arg(KGlobal::locale()->formatNumber(s/1024+.005,2));
+ text = TQString("%1 kB").tqarg(KGlobal::locale()->formatNumber(s/1024+.005,2));
else if (s < 100 * 1024)
- text = TQString("%1 kB").arg(KGlobal::locale()->formatNumber(s/1024+.05,1));
+ text = TQString("%1 kB").tqarg(KGlobal::locale()->formatNumber(s/1024+.05,1));
else if (s < 1000 * 1024)
- text = TQString("%1 kB").arg((int)(s/1024+.5));
+ text = TQString("%1 kB").tqarg((int)(s/1024+.5));
else if (s < 10 * 1024 * 1024)
- text = TQString("%1 MB").arg(KGlobal::locale()->formatNumber(s/1024/1024+.005,2));
+ text = TQString("%1 MB").tqarg(KGlobal::locale()->formatNumber(s/1024/1024+.005,2));
else if (s < 100 * 1024 * 1024)
- text = TQString("%1 MB").arg(KGlobal::locale()->formatNumber(s/1024/1024+.05,1));
+ text = TQString("%1 MB").tqarg(KGlobal::locale()->formatNumber(s/1024/1024+.05,1));
else if (s < 1000 * 1024 * 1024)
- text = TQString("%1 MB").arg((int)(s/1024/1024+.5));
+ text = TQString("%1 MB").tqarg((int)(s/1024/1024+.5));
else
- text = TQString("%1 GB").arg(KGlobal::locale()->formatNumber(s/1024/1024/1024+.005,2));
+ text = TQString("%1 GB").tqarg(KGlobal::locale()->formatNumber(s/1024/1024/1024+.005,2));
if (_sizeEstimation>0) text += "+";
return text;
@@ -354,10 +354,10 @@ TQString Inode::text(int i) const
if (f>0) {
while (f>1000) {
- text = TQString("%1 %2").arg(TQString::number(f).right(3)).arg(text);
+ text = TQString("%1 %2").tqarg(TQString::number(f).right(3)).tqarg(text);
f /= 1000;
}
- text = TQString("%1 %2").arg(TQString::number(f)).arg(text);
+ text = TQString("%1 %2").tqarg(TQString::number(f)).tqarg(text);
if (_fileCountEstimation>0) text += "+";
}
return text;
diff --git a/konq-plugins/fsview/inode.h b/konq-plugins/fsview/inode.h
index eb1e3dd..d21a689 100644
--- a/konq-plugins/fsview/inode.h
+++ b/konq-plugins/fsview/inode.h
@@ -53,7 +53,7 @@ public:
void setPeer(ScanDir*);
- TreeMapItemList* children();
+ TreeMapItemList* tqchildren();
double value() const;
double size() const;
diff --git a/konq-plugins/fsview/treemap.cpp b/konq-plugins/fsview/treemap.cpp
index cab9809..fc83601 100644
--- a/konq-plugins/fsview/treemap.cpp
+++ b/konq-plugins/fsview/treemap.cpp
@@ -756,7 +756,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value)
_parent = parent;
_sum = 0;
- _children = 0;
+ _tqchildren = 0;
_widget = 0;
_index = -1;
_depth = -1; // not set
@@ -789,7 +789,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
setText(0, text1);
_sum = 0;
- _children = 0;
+ _tqchildren = 0;
_widget = 0;
_index = -1;
_depth = -1; // not set
@@ -801,7 +801,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
TreeMapItem::~TreeMapItem()
{
- if (_children) delete _children;
+ if (_tqchildren) delete _tqchildren;
if (_freeRects) delete _freeRects;
// finally, notify widget about deletion
@@ -842,18 +842,18 @@ void TreeMapItem::redraw()
void TreeMapItem::clear()
{
- if (_children) {
+ if (_tqchildren) {
// delete selected items below this item from selection
if (_widget) _widget->clearSelection(this);
- delete _children;
- _children = 0;
+ delete _tqchildren;
+ _tqchildren = 0;
}
}
-// invalidates current children and forces redraw
-// this is only usefull when children are created on demand in items()
+// invalidates current tqchildren and forces redraw
+// this is only usefull when tqchildren are created on demand in items()
void TreeMapItem::refresh()
{
clear();
@@ -887,9 +887,9 @@ int TreeMapItem::depth() const
bool TreeMapItem::initialized()
{
- if (!_children) {
- _children = new TreeMapItemList;
- _children->setAutoDelete(true);
+ if (!_tqchildren) {
+ _tqchildren = new TreeMapItemList;
+ _tqchildren->setAutoDelete(true);
return false;
}
return true;
@@ -899,16 +899,16 @@ void TreeMapItem::addItem(TreeMapItem* i)
{
if (!i) return;
- if (!_children) {
- _children = new TreeMapItemList;
- _children->setAutoDelete(true);
+ if (!_tqchildren) {
+ _tqchildren = new TreeMapItemList;
+ _tqchildren->setAutoDelete(true);
}
i->setParent(this);
if (sorting(0) == -1)
- _children->append(i); // preserve insertion order
+ _tqchildren->append(i); // preserve insertion order
else
- _children->inSort(i);
+ _tqchildren->inSort(i);
}
@@ -974,17 +974,17 @@ void TreeMapItem::setSorting(int textNo, bool ascending)
_sortAscending = ascending;
_sortTextNo = textNo;
- if (_children && _sortTextNo != -1) _children->sort();
+ if (_tqchildren && _sortTextNo != -1) _tqchildren->sort();
}
void TreeMapItem::resort(bool recursive)
{
- if (!_children) return;
+ if (!_tqchildren) return;
- if (_sortTextNo != -1) _children->sort();
+ if (_sortTextNo != -1) _tqchildren->sort();
if (recursive)
- for (TreeMapItem* i=_children->first(); i; i=_children->next())
+ for (TreeMapItem* i=_tqchildren->first(); i; i=_tqchildren->next())
i->resort(recursive);
}
@@ -1002,13 +1002,13 @@ int TreeMapItem::rtti() const
return 0;
}
-TreeMapItemList* TreeMapItem::children()
+TreeMapItemList* TreeMapItem::tqchildren()
{
- if (!_children) {
- _children = new TreeMapItemList;
- _children->setAutoDelete(true);
+ if (!_tqchildren) {
+ _tqchildren = new TreeMapItemList;
+ _tqchildren->setAutoDelete(true);
}
- return _children;
+ return _tqchildren;
}
void TreeMapItem::clearItemRect()
@@ -1252,7 +1252,7 @@ void TreeMapWidget::setMaxDrawingDepth(int d)
TQString TreeMapWidget::defaultFieldType(int f) const
{
- return i18n("Text %1").arg(f+1);
+ return i18n("Text %1").tqarg(f+1);
}
TQString TreeMapWidget::defaultFieldStop(int) const
@@ -1482,7 +1482,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
if (DEBUG_DRAWING) kdDebug(90100) << "item(" << x << "," << y << "):" << endl;
while (1) {
- TreeMapItemList* list = p->children();
+ TreeMapItemList* list = p->tqchildren();
if (!list)
i = 0;
else {
@@ -1491,11 +1491,11 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
if (DEBUG_DRAWING)
kdDebug(90100) << " Checking " << i->path(0).join("/") << " ("
- << i->itemRect().x() << "/" << i->itemRect().y()
- << "-" << i->itemRect().width()
- << "x" << i->itemRect().height() << ")" << endl;
+ << i->tqitemRect().x() << "/" << i->tqitemRect().y()
+ << "-" << i->tqitemRect().width()
+ << "x" << i->tqitemRect().height() << ")" << endl;
- if (i->itemRect().contains(x, y)) {
+ if (i->tqitemRect().contains(x, y)) {
if (DEBUG_DRAWING) kdDebug(90100) << " .. Got. Index " << idx << endl;
@@ -1513,7 +1513,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
if (DEBUG_DRAWING)
kdDebug(90100) << "item(" << x << "," << y << "): Got "
<< p->path(0).join("/") << " (Size "
- << p->itemRect().width() << "x" << p->itemRect().height()
+ << p->tqitemRect().width() << "x" << p->tqitemRect().height()
<< ", Val " << p->value() << ")" << endl;
}
@@ -1542,16 +1542,16 @@ TreeMapItem* TreeMapWidget::visibleItem(TreeMapItem* i) const
{
if (i) {
/* Must have a visible area */
- while(i && ((i->itemRect().width() <1) ||
- (i->itemRect().height() <1))) {
+ while(i && ((i->tqitemRect().width() <1) ||
+ (i->tqitemRect().height() <1))) {
TreeMapItem* p = i->parent();
if (!p) break;
- int idx = p->children()->findRef(i);
+ int idx = p->tqchildren()->findRef(i);
idx--;
if (idx<0)
i = p;
else
- i = p->children()->at(idx);
+ i = p->tqchildren()->at(idx);
}
}
return i;
@@ -1745,7 +1745,7 @@ TreeMapItem* TreeMapWidget::setTmpRangeSelection(TreeMapItem* i1,
i2 = i2->parent();
if (!i2) return changed;
- TreeMapItemList* list = commonParent->children();
+ TreeMapItemList* list = commonParent->tqchildren();
if (!list) return changed;
TreeMapItem* i = list->first();
@@ -1768,11 +1768,11 @@ void TreeMapWidget::contextMenuEvent( TQContextMenuEvent* e )
{
//kdDebug(90100) << "TreeMapWidget::contextMenuEvent" << endl;
- if ( receivers( TQT_SIGNAL(contextMenuRequested(TreeMapItem*, const TQPoint &)) ) )
+ if ( tqreceivers( TQT_SIGNAL(contextMenuRequested(TreeMapItem*, const TQPoint &)) ) )
e->accept();
if ( e->reason() == TQContextMenuEvent::Keyboard ) {
- TQRect r = (_current) ? _current->itemRect() : _base->itemRect();
+ TQRect r = (_current) ? _current->tqitemRect() : _base->tqitemRect();
TQPoint p = TQPoint(r.left() + r.width()/2, r.top() + r.height()/2);
emit contextMenuRequested(_current, p);
}
@@ -1936,14 +1936,14 @@ void TreeMapWidget::mouseDoubleClickEvent( TQMouseEvent* e )
int nextVisible(TreeMapItem* i)
{
TreeMapItem* p = i->parent();
- if (!p || p->itemRect().isEmpty()) return -1;
+ if (!p || p->tqitemRect().isEmpty()) return -1;
- int idx = p->children()->findRef(i);
+ int idx = p->tqchildren()->findRef(i);
if (idx<0) return -1;
- while (idx < (int)p->children()->count()-1) {
+ while (idx < (int)p->tqchildren()->count()-1) {
idx++;
- TQRect r = p->children()->at(idx)->itemRect();
+ TQRect r = p->tqchildren()->at(idx)->tqitemRect();
if (r.width()>1 && r.height()>1)
return idx;
}
@@ -1954,14 +1954,14 @@ int nextVisible(TreeMapItem* i)
int prevVisible(TreeMapItem* i)
{
TreeMapItem* p = i->parent();
- if (!p || p->itemRect().isEmpty()) return -1;
+ if (!p || p->tqitemRect().isEmpty()) return -1;
- int idx = p->children()->findRef(i);
+ int idx = p->tqchildren()->findRef(i);
if (idx<0) return -1;
while (idx > 0) {
idx--;
- TQRect r = p->children()->at(idx)->itemRect();
+ TQRect r = p->tqchildren()->at(idx)->tqitemRect();
if (r.width()>1 && r.height()>1)
return idx;
}
@@ -2042,24 +2042,24 @@ void TreeMapWidget::keyPressEvent( TQKeyEvent* e )
int newIdx = goBack ? nextVisible(_current) : prevVisible(_current);
if (p && newIdx>=0) {
p->setIndex(newIdx);
- setCurrent(p->children()->at(newIdx), true);
+ setCurrent(p->tqchildren()->at(newIdx), true);
}
}
else if (e->key() == Key_Right) {
int newIdx = goBack ? prevVisible(_current) : nextVisible(_current);
if (p && newIdx>=0) {
p->setIndex(newIdx);
- setCurrent(p->children()->at(newIdx), true);
+ setCurrent(p->tqchildren()->at(newIdx), true);
}
}
else if (e->key() == Key_Down) {
- if (_current->children() && _current->children()->count()>0) {
+ if (_current->tqchildren() && _current->tqchildren()->count()>0) {
int newIdx = _current->index();
if (newIdx<0)
- newIdx = goBack ? (_current->children()->count()-1) : 0;
- if (newIdx>=(int)_current->children()->count())
- newIdx = _current->children()->count()-1;
- newItem = visibleItem(_current->children()->at(newIdx));
+ newIdx = goBack ? (_current->tqchildren()->count()-1) : 0;
+ if (newIdx>=(int)_current->tqchildren()->count())
+ newIdx = _current->tqchildren()->count()-1;
+ newItem = visibleItem(_current->tqchildren()->at(newIdx));
setCurrent(newItem, true);
}
}
@@ -2136,7 +2136,7 @@ void TreeMapWidget::drawTreeMap()
}
else {
// only subitem
- if (!_needsRefresh->itemRect().isValid()) return;
+ if (!_needsRefresh->tqitemRect().isValid()) return;
}
// reset cached font object; it could have been changed
@@ -2154,7 +2154,7 @@ void TreeMapWidget::drawTreeMap()
TQPainter p(this);
tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &p,
TQRect(0, 0, TQWidget::width(), TQWidget::height()),
- colorGroup() );
+ tqcolorGroup() );
}
}
@@ -2198,7 +2198,7 @@ void TreeMapWidget::drawItem(TQPainter* p,
bool isCurrent = _current && item->isChildOf(_current);
- RectDrawing d(item->itemRect());
+ RectDrawing d(item->tqitemRect());
item->setSelected(isSelected);
item->setCurrent(isCurrent);
item->setShaded(_shading);
@@ -2232,25 +2232,25 @@ void TreeMapWidget::drawItems(TQPainter* p,
{
if (DEBUG_DRAWING)
kdDebug(90100) << "+drawItems(" << item->path(0).join("/") << ", "
- << item->itemRect().x() << "/" << item->itemRect().y()
- << "-" << item->itemRect().width() << "x"
- << item->itemRect().height() << "), Val " << item->value()
+ << item->tqitemRect().x() << "/" << item->tqitemRect().y()
+ << "-" << item->tqitemRect().width() << "x"
+ << item->tqitemRect().height() << "), Val " << item->value()
<< ", Sum " << item->sum() << endl;
drawItem(p, item);
item->clearFreeRects();
- TQRect origRect = item->itemRect();
+ TQRect origRect = item->tqitemRect();
int bw = item->borderWidth();
TQRect r = TQRect(origRect.x()+bw, origRect.y()+bw,
origRect.width()-2*bw, origRect.height()-2*bw);
- TreeMapItemList* list = item->children();
+ TreeMapItemList* list = item->tqchildren();
TreeMapItem* i;
bool stopDrawing = false;
- // only subdivide if there are children
+ // only subdivide if there are tqchildren
if (!list || list->count()==0)
stopDrawing = true;
@@ -2283,12 +2283,12 @@ void TreeMapWidget::drawItems(TQPainter* p,
if (stopDrawing) {
if (list) {
- // invalidate rects
+ // tqinvalidate rects
for (i=list->first();i;i=list->next())
i->clearItemRect();
}
// tooltip apears on whole item rect
- item->addFreeRect(item->itemRect());
+ item->addFreeRect(item->tqitemRect());
// if we have space for text...
if ((r.height() < _fontHeight) || (r.width() < _fontHeight)) return;
@@ -2399,7 +2399,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
r.setRect(r.x(), r.y()+sr.height(), r.width(), r.height()-sr.height());
}
- // set selfRect (not occupied by children) for tooltip
+ // set selfRect (not occupied by tqchildren) for tooltip
item->addFreeRect(sr);
if (0) kdDebug(90100) << "Item " << item->path(0).join("/") << ": SelfR "
@@ -2537,7 +2537,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
kdDebug(90100) << "-drawItems(" << item->path(0).join("/") << ")" << endl;
}
-// fills area with a pattern if to small to draw children
+// fills area with a pattern if to small to draw tqchildren
void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r)
{
p->setBrush(TQt::Dense4Pattern);
@@ -2546,7 +2546,7 @@ void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r)
i->addFreeRect(r);
}
-// fills area with a pattern if to small to draw children
+// fills area with a pattern if to small to draw tqchildren
void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r,
TreeMapItemListIterator it, int len, bool goBack)
{
@@ -2845,10 +2845,10 @@ void TreeMapWidget::addVisualizationItems(TQPopupMenu* popup, int id)
popup->insertItem(i18n("Border"), bpopup, id+1);
bpopup->insertItem(i18n("Correct Borders Only"), id+2);
bpopup->insertSeparator();
- bpopup->insertItem(i18n("Width %1").arg(0), id+3);
- bpopup->insertItem(i18n("Width %1").arg(1), id+4);
- bpopup->insertItem(i18n("Width %1").arg(2), id+5);
- bpopup->insertItem(i18n("Width %1").arg(3), id+6);
+ bpopup->insertItem(i18n("Width %1").tqarg(0), id+3);
+ bpopup->insertItem(i18n("Width %1").tqarg(1), id+4);
+ bpopup->insertItem(i18n("Width %1").tqarg(2), id+5);
+ bpopup->insertItem(i18n("Width %1").tqarg(3), id+6);
bpopup->setItemChecked(id+2, skipIncorrectBorder());
bpopup->setItemChecked(id+3, borderWidth()==0);
bpopup->setItemChecked(id+4, borderWidth()==1);
@@ -2955,7 +2955,7 @@ void TreeMapWidget::addFieldStopItems(TQPopupMenu* popup,
connect(popup, TQT_SIGNAL(activated(int)),
this, TQT_SLOT(fieldStopActivated(int)));
- popup->insertItem(i18n("No %1 Limit").arg(fieldType(0)), id);
+ popup->insertItem(i18n("No %1 Limit").tqarg(fieldType(0)), id);
popup->setItemChecked(id, fieldStop(0).isEmpty());
_menuItem = i;
bool foundFieldStop = false;
@@ -3014,7 +3014,7 @@ void TreeMapWidget::addAreaStopItems(TQPopupMenu* popup,
int area = i->width() * i->height();
popup->insertSeparator();
popup->insertItem(i18n("Area of '%1' (%2)")
- .arg(i->text(0)).arg(area), id+1);
+ .tqarg(i->text(0)).tqarg(area), id+1);
if (area == minimalArea()) {
popup->setItemChecked(id+1, true);
foundArea = true;
@@ -3040,9 +3040,9 @@ void TreeMapWidget::addAreaStopItems(TQPopupMenu* popup,
}
popup->insertItem(i18n("Double Area Limit (to %1)")
- .arg(minimalArea()*2), id+5);
+ .tqarg(minimalArea()*2), id+5);
popup->insertItem(i18n("Halve Area Limit (to %1)")
- .arg(minimalArea()/2), id+6);
+ .tqarg(minimalArea()/2), id+6);
}
}
@@ -3079,7 +3079,7 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
int d = i->depth();
popup->insertSeparator();
popup->insertItem(i18n("Depth of '%1' (%2)")
- .arg(i->text(0)).arg(d), id+1);
+ .tqarg(i->text(0)).tqarg(d), id+1);
if (d == maxDrawingDepth()) {
popup->setItemChecked(id+1, true);
foundDepth = true;
@@ -3089,7 +3089,7 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
popup->insertSeparator();
int depth = 2, count;
for (count=0;count<3;count++) {
- popup->insertItem(i18n("Depth %1").arg(depth), id+4+count);
+ popup->insertItem(i18n("Depth %1").tqarg(depth), id+4+count);
if (depth == maxDrawingDepth()) {
popup->setItemChecked(id+4+count, true);
foundDepth = true;
@@ -3100,14 +3100,14 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
if (maxDrawingDepth()>1) {
popup->insertSeparator();
if (!foundDepth) {
- popup->insertItem(i18n("Depth %1").arg(maxDrawingDepth()), id+10);
+ popup->insertItem(i18n("Depth %1").tqarg(maxDrawingDepth()), id+10);
popup->setItemChecked(id+10, true);
}
popup->insertItem(i18n("Decrement (to %1)")
- .arg(maxDrawingDepth()-1), id+2);
+ .tqarg(maxDrawingDepth()-1), id+2);
popup->insertItem(i18n("Increment (to %1)")
- .arg(maxDrawingDepth()+1), id+3);
+ .tqarg(maxDrawingDepth()+1), id+3);
}
}
@@ -3130,13 +3130,13 @@ void TreeMapWidget::saveOptions(KConfigGroup* config, TQString prefix)
int f, fCount = _attr.size();
config->writeEntry(prefix+"FieldCount", fCount);
for (f=0;f<fCount;f++) {
- config->writeEntry(TQString(prefix+"FieldVisible%1").arg(f),
+ config->writeEntry(TQString(prefix+"FieldVisible%1").tqarg(f),
_attr[f].visible);
- config->writeEntry(TQString(prefix+"FieldForced%1").arg(f),
+ config->writeEntry(TQString(prefix+"FieldForced%1").tqarg(f),
_attr[f].forced);
- config->writeEntry(TQString(prefix+"FieldStop%1").arg(f),
+ config->writeEntry(TQString(prefix+"FieldStop%1").tqarg(f),
_attr[f].stop);
- config->writeEntry(TQString(prefix+"FieldPosition%1").arg(f),
+ config->writeEntry(TQString(prefix+"FieldPosition%1").tqarg(f),
fieldPositionString(f));
}
}
@@ -3180,18 +3180,18 @@ void TreeMapWidget::restoreOptions(KConfigGroup* config, TQString prefix)
int f;
for (f=0;f<num;f++) {
- str = TQString(prefix+"FieldVisible%1").arg(f);
+ str = TQString(prefix+"FieldVisible%1").tqarg(f);
if (config->hasKey(str))
setFieldVisible(f, config->readBoolEntry(str));
- str = TQString(prefix+"FieldForced%1").arg(f);
+ str = TQString(prefix+"FieldForced%1").tqarg(f);
if (config->hasKey(str))
setFieldForced(f, config->readBoolEntry(str));
- str = config->readEntry(TQString(prefix+"FieldStop%1").arg(f));
+ str = config->readEntry(TQString(prefix+"FieldStop%1").tqarg(f));
setFieldStop(f, str);
- str = config->readEntry(TQString(prefix+"FieldPosition%1").arg(f));
+ str = config->readEntry(TQString(prefix+"FieldPosition%1").tqarg(f));
if (!str.isEmpty()) setFieldPosition(f, str);
}
}
diff --git a/konq-plugins/fsview/treemap.h b/konq-plugins/fsview/treemap.h
index 9bacedc..0aa5a9d 100644
--- a/konq-plugins/fsview/treemap.h
+++ b/konq-plugins/fsview/treemap.h
@@ -215,7 +215,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
*
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
* items on demand, reimplement children().
*/
class TreeMapItem: public StoredDrawParams
{
@@ -250,7 +250,7 @@ public:
// force a redraw of this item
void redraw();
// delete all children
void clear();
// force new child generation & refresh
@@ -290,7 +290,7 @@ public:
*/
void setItemRect(const TQRect& r) { _rect = r; }
void clearItemRect();
- const TQRect& itemRect() const { return _rect; }
+ const TQRect& tqitemRect() const { return _rect; }
int width() const { return _rect.width(); }
int height() const { return _rect.height(); }
@@ -343,7 +343,7 @@ public:
* For value() sorting, use <textNo> = -2
*
* For fast sorting, set this to -1 before child insertions and call
* again after inserting all children.
*/
void setSorting(int textNo, bool ascending = true);
@@ -351,18 +351,18 @@ public:
* Resort according to the already set sorting.
*
* This has to be done if the sorting base changes (e.g. text or values
* change). If this is only true for the children of this item, you can
* set the recursive parameter to false.
*/
void resort(bool recursive = true);
virtual SplitMode splitMode() const;
virtual int rtti() const;
- // not const as this can create children on demand
- virtual TreeMapItemList* children();
+ // not const as this can create tqchildren on demand
+ virtual TreeMapItemList* tqchildren();
protected:
- TreeMapItemList* _children;
+ TreeMapItemList* _tqchildren;
double _sum, _value;
private:
@@ -372,7 +372,7 @@ private:
int _sortTextNo;
bool _sortAscending;
- // temporary layout
+ // temporary tqlayout
TQRect _rect;
TQPtrList<TQRect>* _freeRects;
int _depth;
@@ -436,7 +436,7 @@ public:
/**
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
* has no selected children or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -452,7 +452,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
* Clear selection of all selected items which are children of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
*/
@@ -464,7 +464,7 @@ public:
* Range means for a hierarchical widget:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
* range of direct children between but excluding the child
* leading to i1 and the child leading to i2.
*/
void setRangeSelection(TreeMapItem* i1,
@@ -517,7 +517,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
* If a children value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
* parent/child size relation can not be mapped to a correct
@@ -629,7 +629,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
* Redraws an item with all children.
* This takes changed values(), sums(), colors() and text() into account.
*/
void redraw(TreeMapItem*);
@@ -215,7 +215,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
* If you want more flexibility, reimplement TreeMapItem and
* override the corresponding methods. For dynamic creation of child
- * items on demand, reimplement children().
+ * items on demand, reimplement tqchildren().
*/
class TreeMapItem: public StoredDrawParams
@@ -250,7 +250,7 @@ public:
// force a redraw of this item
void redraw();
- // delete all children
+ // delete all tqchildren
void clear();
// force new child generation & refresh
@@ -343,7 +343,7 @@ public:
*
* For fast sorting, set this to -1 before child insertions and call
- * again after inserting all children.
+ * again after inserting all tqchildren.
*/
void setSorting(int textNo, bool ascending = true);
@@ -351,18 +351,18 @@ public:
*
* This has to be done if the sorting base changes (e.g. text or values
- * change). If this is only true for the children of this item, you can
+ * change). If this is only true for the tqchildren of this item, you can
* set the recursive parameter to false.
*/
@@ -436,7 +436,7 @@ public:
* Selects or unselects an item.
* In multiselection mode, the constrain that a selected item
- * has no selected children or parents stays true.
+ * has no selected tqchildren or parents stays true.
*/
void setSelected(TreeMapItem*, bool selected = true);
@@ -452,7 +452,7 @@ public:
void setMarked(int markNo = 1, bool redraw = true);
/**
- * Clear selection of all selected items which are children of
+ * Clear selection of all selected items which are tqchildren of
* parent. When parent == 0, clears whole selection
* Returns true if selection changed.
@@ -464,7 +464,7 @@ public:
* - select/unselect i1 and i2 according selected
* - search common parent of i1 and i2, and select/unselect the
- * range of direct children between but excluding the child
+ * range of direct tqchildren between but excluding the child
* leading to i1 and the child leading to i2.
*/
@@ -517,7 +517,7 @@ public:
void setVisibleWidth(int width, bool reuseSpace = false);
/**
- * If a children value() is almost the parents sum(),
+ * If a tqchildren value() is almost the parents sum(),
* it can happen that the border to be drawn for visibilty of
* nesting relations takes to much space, and the
@@ -629,7 +629,7 @@ public:
virtual TQString tipString(TreeMapItem* i) const;
/**
- * Redraws an item with all children.
+ * Redraws an item with all tqchildren.
* This takes changed values(), sums(), colors() and text() into account.
*/